@@ -1,12 +1,15 @@
+/* eslint-env node, mocha */
+'use strict';
+
 var assert = require('assert');
 var elliptic = require('../');
-var Signature = require('../lib/elliptic/ec/signature')
+var Signature = require('../lib/elliptic/ec/signature');
 var BN = require('bn.js');
 var hash = require('hash.js');
 
 var entropy = [
   1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
-  21, 22, 23, 24, 25
+  21, 22, 23, 24, 25,
 ];
 
 var msg = 'deadbeef';
@@ -16,6 +19,7 @@ describe('ECDSA', function() {
     describe('curve ' + name, function() {
       var curve;
       var ecdsa;
+      var keys;
 
       beforeEach(function() {
         curve = elliptic.curves[name];
@@ -23,7 +27,7 @@ describe('ECDSA', function() {
 
         ecdsa = new elliptic.ec(curve);
         keys = ecdsa.genKeyPair({
-          entropy: entropy
+          entropy: entropy,
         });
       });
 
@@ -32,7 +36,7 @@ describe('ECDSA', function() {
         if (name === 'p384') {
           keylen = 96;
         } else if (name === 'p521') {
-          keylen = 132
+          keylen = 132;
         }
         // Get keys out of pair
         assert(keys.getPublic().x && keys.getPublic().y);
@@ -70,7 +74,7 @@ describe('ECDSA', function() {
           k: function(iter) {
             assert(iter >= 0);
             return new BN(1358);
-          }
+          },
         });
         assert(ecdsa.verify(msg, sign, keys), 'custom-k verify');
       });
@@ -79,7 +83,7 @@ describe('ECDSA', function() {
         var sign1 = keys.sign(msg);
         var sign2 = keys.sign(msg, { pers: '1234', persEnc: 'hex' });
         assert.notEqual(sign1.r.toArray().concat(sign1.s.toArray()),
-                        sign2.r.toArray().concat(sign2.s.toArray()));
+          sign2.r.toArray().concat(sign2.s.toArray()));
       });
 
       it('should load public key from compact hex value', function() {
@@ -133,7 +137,7 @@ describe('ECDSA', function() {
       opt.cases.forEach(function(c) {
         var ecdsa = elliptic.ec({
           curve: opt.curve,
-          hash: c.hash
+          hash: c.hash,
         });
         var descr = 'should not fail on "' + opt.name + '" ' +
                     'and hash ' + c.hash.name + ' on "' + c.message + '"';
@@ -143,9 +147,9 @@ describe('ECDSA', function() {
           assert.equal(sign.r.toString(16), c.r);
           assert.equal(sign.s.toString(16), c.s);
           assert.ok(ecdsa.keyFromPublic(opt.pub).validate().result,
-                    'Invalid public key');
+            'Invalid public key');
           assert.ok(ecdsa.verify(dgst, sign, opt.pub),
-                    'Invalid signature');
+            'Invalid signature');
         });
       });
     }
@@ -156,34 +160,34 @@ describe('ECDSA', function() {
       key: '6fab034934e4c0fc9ae67f5b5659a9d7d1fefd187ee09fd4',
       pub: {
         x: 'ac2c77f529f91689fea0ea5efec7f210d8eea0b9e047ed56',
-        y: '3bc723e57670bd4887ebc732c523063d0a7c957bc97c1c43'
+        y: '3bc723e57670bd4887ebc732c523063d0a7c957bc97c1c43',
       },
       cases: [
         {
           message: 'sample',
           hash: hash.sha224,
           r: 'a1f00dad97aeec91c95585f36200c65f3c01812aa60378f5',
-          s: 'e07ec1304c7c6c9debbe980b9692668f81d4de7922a0f97a'
+          s: 'e07ec1304c7c6c9debbe980b9692668f81d4de7922a0f97a',
         },
         {
           message: 'sample',
           hash: hash.sha256,
           r: '4b0b8ce98a92866a2820e20aa6b75b56382e0f9bfd5ecb55',
-          s: 'ccdb006926ea9565cbadc840829d8c384e06de1f1e381b85'
+          s: 'ccdb006926ea9565cbadc840829d8c384e06de1f1e381b85',
         },
         {
           message: 'test',
           hash: hash.sha224,
           r: '6945a1c1d1b2206b8145548f633bb61cef04891baf26ed34',
-          s: 'b7fb7fdfc339c0b9bd61a9f5a8eaf9be58fc5cba2cb15293'
+          s: 'b7fb7fdfc339c0b9bd61a9f5a8eaf9be58fc5cba2cb15293',
         },
         {
           message: 'test',
           hash: hash.sha256,
           r: '3a718bd8b4926c3b52ee6bbe67ef79b18cb6eb62b1ad97ae',
-          s: '5662e6848a4a19b1f1ae2f72acd4b8bbe50f1eac65d9124f'
-        }
-      ]
+          s: '5662e6848a4a19b1f1ae2f72acd4b8bbe50f1eac65d9124f',
+        },
+      ],
     });
 
     test({
@@ -192,34 +196,34 @@ describe('ECDSA', function() {
       key: 'f220266e1105bfe3083e03ec7a3a654651f45e37167e88600bf257c1',
       pub: {
         x: '00cf08da5ad719e42707fa431292dea11244d64fc51610d94b130d6c',
-        y: 'eeab6f3debe455e3dbf85416f7030cbd94f34f2d6f232c69f3c1385a'
+        y: 'eeab6f3debe455e3dbf85416f7030cbd94f34f2d6f232c69f3c1385a',
       },
       cases: [
         {
           message: 'sample',
           hash: hash.sha224,
           r: '1cdfe6662dde1e4a1ec4cdedf6a1f5a2fb7fbd9145c12113e6abfd3e',
-          s: 'a6694fd7718a21053f225d3f46197ca699d45006c06f871808f43ebc'
+          s: 'a6694fd7718a21053f225d3f46197ca699d45006c06f871808f43ebc',
         },
         {
           message: 'sample',
           hash: hash.sha256,
           r: '61aa3da010e8e8406c656bc477a7a7189895e7e840cdfe8ff42307ba',
-          s: 'bc814050dab5d23770879494f9e0a680dc1af7161991bde692b10101'
+          s: 'bc814050dab5d23770879494f9e0a680dc1af7161991bde692b10101',
         },
         {
           message: 'test',
           hash: hash.sha224,
           r: 'c441ce8e261ded634e4cf84910e4c5d1d22c5cf3b732bb204dbef019',
-          s: '902f42847a63bdc5f6046ada114953120f99442d76510150f372a3f4'
+          s: '902f42847a63bdc5f6046ada114953120f99442d76510150f372a3f4',
         },
         {
           message: 'test',
           hash: hash.sha256,
           r: 'ad04dde87b84747a243a631ea47a1ba6d1faa059149ad2440de6fba6',
-          s: '178d49b1ae90e3d8b629be3db5683915f4e8c99fdf6e666cf37adcfd'
-        }
-      ]
+          s: '178d49b1ae90e3d8b629be3db5683915f4e8c99fdf6e666cf37adcfd',
+        },
+      ],
     });
 
     test({
@@ -228,34 +232,34 @@ describe('ECDSA', function() {
       key: 'c9afa9d845ba75166b5c215767b1d6934e50c3db36e89b127b8a622b120f6721',
       pub: {
         x: '60fed4ba255a9d31c961eb74c6356d68c049b8923b61fa6ce669622e60f29fb6',
-        y: '7903fe1008b8bc99a41ae9e95628bc64f2f1b20c2d7e9f5177a3c294d4462299'
+        y: '7903fe1008b8bc99a41ae9e95628bc64f2f1b20c2d7e9f5177a3c294d4462299',
       },
       cases: [
         {
           message: 'sample',
           hash: hash.sha224,
           r: '53b2fff5d1752b2c689df257c04c40a587fababb3f6fc2702f1343af7ca9aa3f',
-          s: 'b9afb64fdc03dc1a131c7d2386d11e349f070aa432a4acc918bea988bf75c74c'
+          s: 'b9afb64fdc03dc1a131c7d2386d11e349f070aa432a4acc918bea988bf75c74c',
         },
         {
           message: 'sample',
           hash: hash.sha256,
           r: 'efd48b2aacb6a8fd1140dd9cd45e81d69d2c877b56aaf991c34d0ea84eaf3716',
-          s: 'f7cb1c942d657c41d436c7a1b6e29f65f3e900dbb9aff4064dc4ab2f843acda8'
+          s: 'f7cb1c942d657c41d436c7a1b6e29f65f3e900dbb9aff4064dc4ab2f843acda8',
         },
         {
           message: 'test',
           hash: hash.sha224,
           r: 'c37edb6f0ae79d47c3c27e962fa269bb4f441770357e114ee511f662ec34a692',
-          s: 'c820053a05791e521fcaad6042d40aea1d6b1a540138558f47d0719800e18f2d'
+          s: 'c820053a05791e521fcaad6042d40aea1d6b1a540138558f47d0719800e18f2d',
         },
         {
           message: 'test',
           hash: hash.sha256,
           r: 'f1abb023518351cd71d881567b1ea663ed3efcf6c5132b354f28d3b0b7d38367',
-          s: '19f4113742a2b14bd25926b49c649155f267e60d3814b4c0cc84250e46f0083'
-        }
-      ]
+          s: '19f4113742a2b14bd25926b49c649155f267e60d3814b4c0cc84250e46f0083',
+        },
+      ],
     });
 
     test({
@@ -267,7 +271,7 @@ describe('ECDSA', function() {
         x: 'ec3a4e415b4e19a4568618029f427fa5da9a8bc4ae92e02e06aae5286b30' +
            '0c64def8f0ea9055866064a254515480bc13',
         y: '8015d9b72d7d57244ea8ef9ac0c621896708a59367f9dfb9f54ca84b3f' +
-           '1c9db1288b231c3ae0d4fe7344fd2533264720'
+           '1c9db1288b231c3ae0d4fe7344fd2533264720',
       },
       cases: [
         {
@@ -276,7 +280,7 @@ describe('ECDSA', function() {
           r: '42356e76b55a6d9b4631c865445dbe54e056d3b3431766d05092447' +
              '93c3f9366450f76ee3de43f5a125333a6be060122',
           s: '9da0c81787064021e78df658f2fbb0b042bf304665db721f077a429' +
-             '8b095e4834c082c03d83028efbf93a3c23940ca8d'
+             '8b095e4834c082c03d83028efbf93a3c23940ca8d',
         },
         {
           message: 'sample',
@@ -284,7 +288,7 @@ describe('ECDSA', function() {
           r: '94edbb92a5ecb8aad4736e56c691916b3f88140666ce9fa73d6' +
              '4c4ea95ad133c81a648152e44acf96e36dd1e80fabe46',
           s: '99ef4aeb15f178cea1fe40db2603138f130e740a19624526203b' +
-             '6351d0a3a94fa329c145786e679e7b82c71a38628ac8'
+             '6351d0a3a94fa329c145786e679e7b82c71a38628ac8',
         },
         {
           message: 'test',
@@ -292,9 +296,9 @@ describe('ECDSA', function() {
           r: '8203b63d3c853e8d77227fb377bcf7b7b772e97892a80f36a' +
              'b775d509d7a5feb0542a7f0812998da8f1dd3ca3cf023db',
           s: 'ddd0760448d42d8a43af45af836fce4de8be06b485e9b61b827c2f13' +
-             '173923e06a739f040649a667bf3b828246baa5a5'
-        }
-      ]
+             '173923e06a739f040649a667bf3b828246baa5a5',
+        },
+      ],
     });
 
     test({
@@ -308,7 +312,7 @@ describe('ECDSA', function() {
            '71123d46e45db6b5d5370a7f20fb633155d38ffa16d2bd761dcac474b9a2f502' +
            '3a4',
         y: '0493101c962cd4d2fddf782285e64584139c2f91b47f87ff82354d6630f746a2' +
-           '8a0db25741b5b34a828008b22acc23f924faafbd4d33f81ea66956dfeaa2bfdfcf5'
+           '8a0db25741b5b34a828008b22acc23f924faafbd4d33f81ea66956dfeaa2bfdfcf5',
       },
       cases: [
         {
@@ -319,7 +323,7 @@ describe('ECDSA', function() {
              'd50c67451',
           s: '1f21a3cee066e1961025fb048bd5fe2b7924d0cd797babe0a83b66f1e35ee' +
              'af5fde143fa85dc394a7dee766523393784484bdf3e00114a1c857cde1aa2' +
-             '03db65d61'
+             '03db65d61',
         },
         {
           message: 'sample',
@@ -329,7 +333,7 @@ describe('ECDSA', function() {
              '77fa',
           s: '617cce7cf5064806c467f678d3b4080d6f1cc50af26ca209417308281b68af2' +
              '82623eaa63e5b5c0723d8b8c37ff0777b1a20f8ccb1dccc43997f1ee0e44da4' +
-             'a67a'
+             'a67a',
         },
         {
           message: 'test',
@@ -339,9 +343,9 @@ describe('ECDSA', function() {
              'babd47ee6d',
           s: '1fbd0013c674aa79cb39849527916ce301c66ea7ce8b80682786ad60f98' +
              'f7e78a19ca69eff5c57400e3b3a0ad66ce0978214d13baf4e9ac60752f7b15' +
-             '5e2de4dce3'
-        }
-      ]
+             '5e2de4dce3',
+        },
+      ],
     });
   });
 
@@ -362,7 +366,7 @@ describe('ECDSA', function() {
              'd0c6b2d5217a5c16e8371062737aa1dae1',
         message: msg,
         sig: '3006020106020104',
-        result: true
+        result: true,
       },
       {
         curve: p256,
@@ -371,7 +375,7 @@ describe('ECDSA', function() {
              '4cfbc761c12edae974a0759750c8324f9a',
         message: msg,
         sig: '3006020106020104',
-        result: true
+        result: true,
       },
       {
         curve: p256,
@@ -380,7 +384,7 @@ describe('ECDSA', function() {
              'ddc39e8367147abab3084142ed3ea170e4',
         message: msg,
         sig: '301502104319055358e8617b0c46353d039cdaae020104',
-        result: true
+        result: true,
       },
       {
         curve: p256,
@@ -389,7 +393,7 @@ describe('ECDSA', function() {
              '8a560fff30a3d14aa160be0c5e7edcd887',
         message: msg,
         sig: '301502104319055358e8617b0c46353d039cdaae020104',
-        result: false
+        result: false,
       },
       {
         curve: p384,
@@ -399,7 +403,7 @@ describe('ECDSA', function() {
              '463c6186864888f6c0b67b304441f82aab031279e48f047c31',
         message: msg,
         sig: '3006020103020104',
-        result: true
+        result: true,
       },
       {
         curve: p384,
@@ -409,7 +413,7 @@ describe('ECDSA', function() {
              '526a7dfe616091b78d293552bc093dfde9b31cae69d51d3afb',
         message: msg,
         sig: '3006020103020104',
-        result: true
+        result: true,
       },
       {
         curve: p384,
@@ -419,7 +423,7 @@ describe('ECDSA', function() {
              '417c83dbcad631421f360d84d64658c98a62d685b220f5aad4',
         message: msg,
         sig: '301d0218389cb27e0bc8d21fa7e5f24cb74f58851313e696333ad68e020104',
-        result: true
+        result: true,
       },
       {
         curve: p384,
@@ -429,8 +433,8 @@ describe('ECDSA', function() {
              '2ef2f20d679777b84192ce86e781c14b1bbb77eacd6e0520e2',
         message: msg,
         sig: '301d0218389cb27e0bc8d21fa7e5f24cb74f58851313e696333ad68e020104',
-        result: false
-      }
+        result: false,
+      },
     ];
 
     vectors.forEach(function(vector, i) {
@@ -453,7 +457,7 @@ describe('ECDSA', function() {
     var ecdsa = new elliptic.ec(curve);
     var keys = ecdsa.genKeyPair({
       pers: 'my.pers.string',
-      entropy: hash.sha256().update('hello world').digest()
+      entropy: hash.sha256().update('hello world').digest(),
     });
     assert.equal(
       keys.getPrivate('hex'),
@@ -471,19 +475,19 @@ describe('ECDSA', function() {
   });
 
   it('should fail to recover key when no quadratic residue available',
-     function() {
-    var ec = new elliptic.ec('secp256k1');
+    function() {
+      var ec = new elliptic.ec('secp256k1');
 
-    var message =
+      var message =
         'f75c6b18a72fabc0f0b888c3da58e004f0af1fe14f7ca5d8c897fe164925d5e9';
 
-    assert.throws(function() {
-      ecdsa.recoverPubKey(message, {
-        r: 'fffffffffffffffffffffffffffffffebaaedce6af48a03bbfd25e8cd0364140',
-        s: '8887321be575c8095f789dd4c743dfe42c1820f9231f98a962b210e3ac2452a3'
-      }, 0);
+      assert.throws(function() {
+        ec.recoverPubKey(message, {
+          r: 'fffffffffffffffffffffffffffffffebaaedce6af48a03bbfd25e8cd0364140',
+          s: '8887321be575c8095f789dd4c743dfe42c1820f9231f98a962b210e3ac2452a3',
+        }, 0);
+      });
     });
-  });
 
   describe('Signature', function () {
     it('recoveryParam is 0', function () {
